=== added file 'pics/arrow-right.png'
Binary files pics/arrow-right.png and pics/arrow-right.png differ
=== added file 'scripting/format_help.lua'
--- scripting/format_help.lua	1970-01-01 00:00:00 +0000
+++ scripting/format_help.lua	2012-03-01 20:53:33 +0000
@@ -0,0 +1,98 @@
+-- RST
+-- format_help.lua
+-- ---------------
+--
+-- Functions used in the ingame help windows for formatting the text and pictures.
+
+-- RST
+-- .. function:: image_line_dep(image1, image2, image3[, text = nil])
+--
+--    Creates a dependencies line.
+--
+--    :arg image1-3: images in the correct order from left to right from ressource
+--       to the following worker.
+--    :arg text: normally the name of the worker.
+--    :returns: a row of pictures connected by arrows. If there is no text the
+--       row will be aligned right else left with following text.
+--
+function image_line_dep(image1, image2, image3, text)
+	local imgs={image1, "pics/arrow-right.png", image2, "pics/arrow-right.png", image3}
+	local imgstr = table.concat(imgs, ";")
+
+	if text then
+		return rt("image=" .. imgstr, text)
+	else
+		return rt("image=" .. imgstr .. " image-align=right", "")
+	end
+end
+
+-- RST
+-- .. function:: image_line_head(image, count[, text = nil])
+--
+--    Aligns the image to a row on the right side with text on the left.
+--
+--    :arg image: the picture to be aligned to a row.
+--    :arg count: length of the picture row.
+--    :arg text: if given the text aligned on the left side, formatted via
+--       formatting.lua functions.
+--    :returns: the text on the left and a picture row on the right.
+--
+function image_line_text(image, count, text)
+	local imgs={}
+	for i=1,count do
+		imgs[#imgs + 1] = image
+	end
+	local imgstr = table.concat(imgs, ";")
+
+	if text then
+		return rt("image=" .. imgstr .. " image-align=right", "  " .. text)
+	else
+		return rt("image=" .. imgstr .. " image-align=right", "")
+	end
+end
+
+-- RST
+-- .. function text_line(t1, t2)
+--
+--    Creates a line of h3 formatted text followed by normal text.
+--
+--    :arg t1: text in h3 format.
+--    :arg t2: text in p format.
+--    :returns: header followed by normal text.
+--
+function text_line(t1, t2)
+	return "<rt text-align=left><p font-size=13 font-color=D1D1D1>" ..  t1 ..
+		"</p><p line-spacing=3 font-size=12>" .. t2 .. "<br></p><p font-size=8> <br></p></rt>"
+end
+
+-- h3-Header, Text, Image
+function text_image_line(t1, t2, imgstr)
+	return "<rt text-align=left image=" .. imgstr .. " image-align=right><p font-size=13 font-color=D1D1D1>" ..  t1 ..
+		"</p><p line-spacing=3 font-size=12>" .. t2 .. "<br></p><p font-size=8> <br></p></rt>"
+end
+
+-- Two images connected by arrows followed by text.
+function image_line_out(image1, image2, text)
+	local imgs={image1, "pics/arrow-right.png", image2}
+	local imgstr = table.concat(imgs, ";")
+
+	if text then
+		return rt("image=" .. imgstr, text)
+	else
+		return rt("image=" .. imgstr .. " image-align=right", "")
+	end
+end
+
+-- Tabs für die Hilfe, weiß aber nicht, ob das wirklich so funktionieren kann,
+-- oder wie ich das eigentlich anwenden muss… Oder was ich falsch mache…
+function make_tabs_array(t1, t2)
+  return { {
+        text = t1,
+        tab_picture = "pics/small.png", -- Graphic for the tab button
+     },
+     {
+        text = t2,
+        tab_picture = "pics/medium.png",
+     }
+  }
+end
\ No newline at end of file

=== added file 'tribes/barbarians/coalmine/help.lua'
--- tribes/barbarians/coalmine/help.lua	1970-01-01 00:00:00 +0000
+++ tribes/barbarians/coalmine/help.lua	2012-03-01 20:53:33 +0000
@@ -0,0 +1,58 @@
+use("aux", "formatting")
+use("aux", "format_help")
+
+set_textdomain("tribe_barbarians")
+
+return {
+	text =
+		rt(h1(_"The Barbarian Coal Mine")) ..
+	--Lore Section
+		rt(h2(_"Lore")) ..
+		rt("image=tribes/barbarians/coalmine/coalmine_i_00.png", p(_
+			[[Ages ago, the Barbarians learned to delve into mountainsides for that black material that feeds their furnaces. <br>
+			Wood may serve for a household fire and to keep you warm, but when it comes to working with iron or gold, there is no way around coal.]]
+		)) ..
+	--General Section
+		rt(h2(_"General")) ..
+		rt(p(_"Coal Mines exploit only 1/3 of the resource. <br>" .. _"From there on, they will only have a 5% chance of finding coal.")) ..
+		rt(h3(_"Purpose:")) ..
+		image_line_text("tribes/barbarians/coal/menu.png", 1, p(_"Dig coal out of the ground in mountain terrain.")) ..
+		text_line(_"Working radius:", "2") ..
+		text_line(_"Conquer range:", "n/a") ..
+		text_line(_"Vision range:", "4") ..
+	--Dependencies
+		rt(h2(_"Dependencies")) ..
+		rt(h3(_"Incoming:")) ..
+		image_line_dep("tribes/barbarians/tavern/menu.png","tribes/barbarians/ration/menu.png","tribes/barbarians/coalmine/menu.png", p(_"Rations from a Tavern")) ..
+		image_line_dep("tribes/barbarians/inn/menu.png","tribes/barbarians/ration/menu.png","tribes/barbarians/coalmine/menu.png", p(_"Rations from an Inn")) ..
+		image_line_dep("tribes/barbarians/big_inn/menu.png","tribes/barbarians/ration/menu.png","tribes/barbarians/coalmine/menu.png", p(_"Rations from a Big Inn")) ..
+		rt(h3(_"Outgoing:")) ..
+		image_line_dep("tribes/barbarians/resi_coal2/resi_00.png","tribes/barbarians/coalmine/menu.png","tribes/barbarians/coal/menu.png", p(_"Coal")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/metalworks/menu.png", p(_"Metalwork Shop")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/axefactory/menu.png", p(_"Axefactory")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/warmill/menu.png", p(_"War Mill")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/helmsmithy/menu.png", p(_"Helmsmithy")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/smelting_works/menu.png", p(_"Smelting Works")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/lime_kiln/menu.png", p(_"Lime Kiln")) ..
+	--Building Section
+		rt(h2(_"Building")) ..
+		text_image_line(_"Space required:",_"Mine plot","pics/mine.png") ..
+		text_line(_"Upgraded from:", "n/a") ..
+		rt(h3(_"Build Cost:")) ..
+		image_line_text("tribes/barbarians/raw_stone/menu.png", 2, p("2 " .. _"Raw Stone")) ..
+		image_line_text("tribes/barbarians/trunk/menu.png", 4, p("4 " .. _"Trunk")) ..
+		rt(h3(_"Dismantle yields:")) ..
+		image_line_text("tribes/barbarians/raw_stone/menu.png", 1, p("1 " .. _"Raw Stone")) ..
+		image_line_text("tribes/barbarians/trunk/menu.png", 2, p("2 " .. _"Trunk")) ..
+		text_image_line(_"Upgradeable to:",_"Deep Coal Mine","tribes/barbarians/deep_coalmine/menu.png") ..
+	--Workers Section
+		rt(h2(_"Workers")) ..
+		rt(h3(_"Crew required:")) ..
+		image_line_text("tribes/barbarians/miner/menu.png", 1, p("1 " .. _"Miner" .. _" or better" .. ".")) ..
+		text_image_line(_"Worker uses:",_"Pick","tribes/barbarians/pick/menu.png") ..
+		rt(h3(_"Experience levels:")) ..
+		rt("text-align=right", p(_"Miner" .. _" to " .. _"Chief Miner" .. " (19 " .. _"EP" .. ")<br>" .. _"Chief Miner" .. _" to " .. _"Master Miner" .. " (28 " .. _"EP" ..")")) ..
+	--Production Section
+		rt(h2(_"Production")) ..
+		text_line(_"Performance:", _"If the food supply is steady, a Coal Mine can produce one coal in 32.5s on average.")
+}

=== added file 'tribes/barbarians/deep_coalmine/help.lua'
--- tribes/barbarians/deep_coalmine/help.lua	1970-01-01 00:00:00 +0000
+++ tribes/barbarians/deep_coalmine/help.lua	2012-03-01 20:53:33 +0000
@@ -0,0 +1,61 @@
+use("aux", "formatting")
+use("aux", "format_help")
+
+set_textdomain("tribe_barbarians")
+
+return {
+	text =
+		rt(h1(_"The Barbarian Deep Coal Mine")) ..
+	--Lore Section
+		rt(h2(_"Lore")) ..
+		rt("image=tribes/barbarians/deep_coalmine/deep_coalmine_i_00.png", p(_ --text identical to coalmine
+			[[Ages ago, the Barbarians learned to delve into mountainsides for that black material that feeds their furnaces. <br>
+			Wood may serve for a household fire and to keep you warm, but when it comes to working with iron or gold, there is no way around coal.]]
+		)) ..
+	--General Section
+		rt(h2(_"General")) ..
+		rt(p(_"Deep Coal Mines exploit only 2/3 of the resource.<br>" .. _"From there on, they will only have a 5% chance of finding coal.")) ..
+		rt(h3(_"Purpose:")) ..
+		image_line_text("tribes/barbarians/coal/menu.png", 1, p(_"Dig coal out of the ground in mountain terrain.")) ..
+		text_line(_"Working radius:", "2") ..
+		text_line(_"Conquer range:", "n/a") ..
+		text_line(_"Vision range:", "4") ..
+	--Dependencies
+		rt(h2(_"Dependencies")) ..
+		rt(h3(_"Incoming:")) ..
+		image_line_dep("tribes/barbarians/inn/menu.png","tribes/barbarians/snack/menu.png","tribes/barbarians/deep_coalmine/menu.png", p(_"Snacks from an Inn")) ..
+		image_line_dep("tribes/barbarians/big_inn/menu.png","tribes/barbarians/snack/menu.png","tribes/barbarians/deep_coalmine/menu.png", p(_"Snacks from a Big Inn")) ..
+		rt(h3(_"Outgoing:")) ..
+		image_line_dep("tribes/barbarians/resi_coal2/resi_00.png","tribes/barbarians/deep_coalmine/menu.png","tribes/barbarians/coal/menu.png", p(_"Coal")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/metalworks/menu.png", p(_"Metalwork Shop")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/axefactory/menu.png", p(_"Axefactory")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/warmill/menu.png", p(_"War Mill")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/helmsmithy/menu.png", p(_"Helmsmithy")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/smelting_works/menu.png", p(_"Smelting Works")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/lime_kiln/menu.png", p(_"Lime Kiln")) ..
+	--Building Section
+		rt(h2(_"Building")) ..
+		text_image_line(_"Space required:",_"Mine plot","pics/mine.png") ..
+		text_image_line(_"Upgraded from:",_"Coal mine","tribes/barbarians/coalmine/menu.png") ..
+		rt(h3(_"Upgrade cost:")) ..
+		image_line_text("tribes/barbarians/raw_stone/menu.png", 2, p("2 " .. _"Raw Stone")) ..
+		image_line_text("tribes/barbarians/trunk/menu.png", 4, p("4 " .. _"Trunk")) ..
+		rt(h3(_"Cost cumulative:")) ..
+		image_line_text("tribes/barbarians/raw_stone/menu.png", 4, p("4 " .. _"Raw Stone")) ..
+		image_line_text("tribes/barbarians/trunk/menu.png", 8, p("8 " .. _"Trunk")) ..
+		rt(h3(_"Dismantle yields:")) ..
+		image_line_text("tribes/barbarians/raw_stone/menu.png", 2, p("2 " .. _"Raw Stone")) ..
+		image_line_text("tribes/barbarians/trunk/menu.png", 4, p("4 " .. _"Trunk")) ..
+		text_image_line(_"Upgradeable to:",_"Deeper Coal Mine","tribes/barbarians/deeper_coalmine/menu.png") ..
+	--Workers Section
+		rt(h2(_"Workers")) ..
+		rt(h3(_"Crew required:")) ..
+		image_line_text("tribes/barbarians/chief-miner/menu.png",1, p("1 " .. _"Chief Miner" .. _" or better" .. _" and")) ..
+		image_line_text("tribes/barbarians/miner/menu.png",1, p("1 " .. _"Miner" .. _" or better" .. ".")) ..
+		text_image_line(_"Workers use:",_"Pick","tribes/barbarians/pick/menu.png") ..
+		rt(h3(_"Experience levels:")) ..
+		rt("text-align=right", p(_"Miner" .. _" to " .. _"Chief Miner" .. " (19 " .. _"EP" .. ")<br>" .. _"Chief Miner" .. _" to " .. _"Master Miner" .. " (28 " .. _"EP" ..")")) ..
+	--Production Section
+		rt(h2(_"Production")) ..
+		text_line(_"Performance:", _"If the food supply is steady, a Deep Coal Mine can produce one coal in 19.5s on average.")
+}
\ No newline at end of file

=== added file 'tribes/barbarians/deeper_coalmine/help.lua'
--- tribes/barbarians/deeper_coalmine/help.lua	1970-01-01 00:00:00 +0000
+++ tribes/barbarians/deeper_coalmine/help.lua	2012-03-01 20:53:33 +0000
@@ -0,0 +1,62 @@
+use("aux", "formatting")
+use("aux", "format_help")
+
+set_textdomain("tribe_barbarians")
+
+return {
+	text =
+		rt(h1(_"The Barbarian Deeper Coal Mine")) ..
+	--Lore Section
+		rt(h2(_"Lore")) ..
+		rt("image=tribes/barbarians/deeper_coalmine/deeper_coalmine_i_00.png", p(_ --text identical to coalmine
+			[[Ages ago, the Barbarians learned to delve into mountainsides for that black material that feeds their furnaces. <br>
+			Wood may serve for a household fire and to keep you warm, but when it comes to working with iron or gold, there is no way around coal.]]
+		)) ..
+	--General Section
+		rt(h2(_"General")) ..
+		rt(p(_"Deeper Coal Mines exploit all of the resource down to the deepest level.<br>" .. _"But even after having done so, they will still have a 10% chance of finding some more coal.")) ..
+		rt(h3(_"Purpose:")) ..
+		image_line_text("tribes/barbarians/coal/menu.png", 1, p(_"Dig coal out of the ground in mountain terrain.")) ..
+		text_line(_"Working radius:", "2") ..
+		text_line(_"Conquer range:", "n/a") ..
+		text_line(_"Vision range:", "4") ..
+	--Dependencies
+		rt(h2(_"Dependencies")) ..
+		rt(h3(_"Incoming:")) ..
+		image_line_dep("tribes/barbarians/big_inn/menu.png","tribes/barbarians/meal/menu.png","tribes/barbarians/deeper_coalmine/menu.png", p(_"Meals from a Big Inn")) ..
+		rt(h3(_"Outgoing:")) ..
+		image_line_dep("tribes/barbarians/resi_coal2/resi_00.png","tribes/barbarians/deeper_coalmine/menu.png","tribes/barbarians/coal/menu.png", p(_"Coal")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/metalworks/menu.png", p(_"Metalwork Shop")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/axefactory/menu.png", p(_"Axefactory")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/warmill/menu.png", p(_"War Mill")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/helmsmithy/menu.png", p(_"Helmsmithy")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/smelting_works/menu.png", p(_"Smelting Works")) ..
+		image_line_out("tribes/barbarians/coal/menu.png","tribes/barbarians/lime_kiln/menu.png", p(_"Lime Kiln")) ..
+	--Building Section
+		rt(h2(_"Building")) ..
+		text_image_line(_"Space required:",_"Mine plot","pics/mine.png") ..
+		text_image_line(_"Upgraded from:",_"Deep Coal Mine","tribes/barbarians/deep_coalmine/menu.png") ..
+		rt(h3(_"Upgrade cost:")) ..
+		image_line_text("tribes/barbarians/raw_stone/menu.png", 2, p("2 " .. _"Raw Stone")) ..
+		image_line_text("tribes/barbarians/trunk/menu.png", 4, p("4 " .. _"Trunk")) ..
+		rt(h3(_"Cost cumulative:")) ..
+		image_line_text("tribes/barbarians/raw_stone/menu.png", 6, p("6 " .. _"Raw Stone")) ..
+		image_line_text("tribes/barbarians/trunk/menu.png", 6, p("12 " .. _"Trunk")) ..
+		image_line_text("tribes/barbarians/trunk/menu.png", 6) ..
+		rt(h3(_"Dismantle yields:")) ..
+		image_line_text("tribes/barbarians/raw_stone/menu.png", 3, p("3 " .. _"Raw Stone")) ..
+		image_line_text("tribes/barbarians/trunk/menu.png", 6, p("6 " .. _"Trunk")) ..
+		text_line(_"Upgradeable to:","n/a") ..
+	--Workers Section
+		rt(h2(_"Workers")) ..
+		rt(h3(_"Crew required:")) ..
+		image_line_text("tribes/barbarians/master-miner/menu.png",1, p("1 " .. _"Master Miner" .. _" or better" .. _" and")) ..
+		image_line_text("tribes/barbarians/chief-miner/menu.png",1, p("1 " .. _"Chief Miner" .. _" or better" .. _" and")) ..
+		image_line_text("tribes/barbarians/miner/menu.png",1, p("1 " .. _"Miner" .. _" or better" .. ".")) ..
+		text_image_line(_"Workers use:",_"Pick","tribes/barbarians/pick/menu.png") ..
+		rt(h3(_"Experience levels:")) ..
+		rt("text-align=right", p(_"Miner" .. _" to " .. _"Chief Miner" .. " (19 " .. _"EP" .. ")<br>" .. _"Chief Miner" .. _" to " .. _"Master Miner" .. " (28 " .. _"EP" ..")")) ..
+	--Production Section
+		rt(h2(_"Production")) ..
+		text_line(_"Performance:", _"If the food supply is steady, a Deeper Coal Mine can produce one coal in 14.4s on average.")
+}
\ No newline at end of file

